==> mcp_imgutils-3.0.1.tar.gz: mcp_imgutils-3.0.1/docs/user-guide-image-generation.md <==
# 🎨 AI图片生成用户指南

本指南将帮助您了解如何通过简单的对话来生成各种用途的AI图片。您无需了解技术细节，只需告诉AI您的需求即可！

## 🎯 基本使用方法

### 最简单的方式
```
用户: 请生成一张美丽的日落风景图片
Claude: [自动选择最佳设置生成图片]
```

**默认设置**: 1920x1080 (Full HD)，适合现代电脑屏幕

## 📋 按用途请求图片

### 🖥️ 桌面和工作用途

#### 桌面壁纸
```
用户: 我需要一张桌面壁纸，主题是宁静的森林
Claude: [选择desktop_2k预设，生成1440x960高质量壁纸]
```

#### 演示文稿
```
用户: 为我的商业演示生成一张现代办公室的图片
Claude: [选择desktop_fhd预设，生成1440x832适合投影的图片]
```

#### 工作文档配图
```
用户: 需要一张简洁的图表背景图，用于报告
Claude: [选择默认16:9比例，生成1920x1080专业图片]
```

### 📱 移动设备用途

#### 手机壁纸
```
用户: 生成一张手机壁纸，主题是星空
Claude: [选择mobile_portrait预设，生成832x1440竖屏壁纸]
```

#### 手机头像
```
用户: 我需要一个卡通风格的头像
Claude: [选择mobile_square预设，生成1024x1024正方形头像]
```

### 🌐 社交媒体用途

#### Instagram帖子
```
用户: 为Instagram制作一张美食照片
Claude: [选择instagram_square预设，生成1024x1024正方形图片]
```

#### Facebook封面
```
用户: 需要一张Facebook页面的封面图片，主题是旅行
Claude: [选择facebook_cover预设，生成1184x640封面图片]
```

#### Twitter横幅
```
用户: 制作一个Twitter账号的横幅，展示科技感
Claude: [选择twitter_banner预设，生成1024x512横幅图片]
```

### 🎬 创意和娱乐用途

#### 电影海报风格
```
用户: 创建一张电影海报风格的图片，科幻主题
Claude: [选择cinema_wide预设，生成1408x576宽屏电影比例]
```

#### 艺术创作
```
用户: 生成一幅抽象艺术作品，用于打印
Claude: [选择portrait_4_3预设，生成1024x768传统打印比例]
```

## 🎨 质量和风格选择

### 不同质量级别

#### 日常使用（免费）
```
用户: 生成一张简单的风景图片
Claude: [使用flux-dev模型，免费且质量良好]
```

#### 高质量需求
```
用户: 我需要一张高质量的产品展示图片
Claude: [使用flux-pro模型，更高质量和细节]
```

#### 超高质量（专业用途）
```
用户: 为专业摄影作品集生成一张超高清人像
Claude: [使用flux-pro-1.1-ultra模型，4MP超高分辨率]
```

## 💡 实用技巧

### 🎯 明确用途，获得最佳效果
- ✅ **好的请求**: "为我的咖啡店制作Instagram帖子图片"
- ❌ **模糊请求**: "生成一张图片"

### 🎨 描述风格和细节
- ✅ **详细描述**: "温暖的咖啡店内景，柔和的灯光，木质家具，有人在阅读"
- ❌ **过于简单**: "咖啡店"

### 📐 让AI选择尺寸
- ✅ **说明用途**: "用作手机壁纸" → AI自动选择竖屏比例
- ✅ **说明平台**: "发布到Instagram" → AI自动选择正方形
- ✅ **说明设备**: "桌面显示器背景" → AI自动选择16:9宽屏

## 🔧 高级用法

### 特定尺寸需求
```
用户: 我需要一张2048x2048的高分辨率正方形图片
Claude: [使用square_large预设或Ultra模型生成大尺寸图片]
```

### 特殊比例需求
```
用户: 制作一张21:9超宽屏比例的壁纸
Claude: [使用cinema_wide预设，生成1408x576超宽屏图片]
```

## 📁 文件管理

生成的图片会自动保存到本地，包含：
- **图片文件**: 高质量JPG格式
- **信息文件**: 同名TXT文件，包含提示词和生成参数
- **智能命名**: 文件名包含时间、模型、尺寸等信息

示例文件名：
```
20250803_141822_flux-dev_1920x1080_beautiful_sunset_landscape_abc123.jpg
20250803_141822_flux-dev_1920x1080_beautiful_sunset_landscape_abc123.txt
```

## 🎉 开始使用

现在您可以开始了！只需告诉AI：
- 您想要什么样的图片
- 用于什么目的
- 任何特殊要求

AI会自动为您选择最佳的设置和参数，生成完美的图片！

---

*💡 提示：不确定如何描述？试试这样开始："我需要一张用于[用途]的[主题]图片"*

==> mcp_imgutils-4.0.0.tar.gz: mcp_imgutils-4.0.0/docs/user-guide-image-generation.md <==
# 🎨 AI图片生成用户指南

## 🎉 全新升级的 MCP ImageUtils

Phase 2 升级后，MCP ImageUtils 现在提供**企业级多模型 AI 图片生成体验**：

- ⚡ **智能缓存**: 相同请求毫秒级响应，节省时间和费用
- 🛠️ **智能配置**: 自动诊断配置问题，提供解决建议
- 🌍 **友好错误**: 中文错误信息和具体解决方案
- 📊 **资源管理**: 自动清理过期文件，优化存储空间
- 🚀 **多模型支持**: 为未来更多 AI 模型做好准备

本指南将帮助您了解如何通过简单的对话来生成各种用途的AI图片。您无需了解技术细节，只需告诉AI您的需求即可！

## 🎯 基本使用方法

### 最简单的方式
```
用户: 请生成一张美丽的日落风景图片
Claude: [自动选择最佳设置生成图片]
```

**默认设置**: 1920x1080 (Full HD)，适合现代电脑屏幕

## 📋 按用途请求图片

### 🖥️ 桌面和工作用途

#### 桌面壁纸
```
用户: 我需要一张桌面壁纸，主题是宁静的森林
Claude: [选择desktop_2k预设，生成1440x960高质量壁纸]
```

#### 演示文稿
```
用户: 为我的商业演示生成一张现代办公室的图片
Claude: [选择desktop_fhd预设，生成1440x832适合投影的图片]
```

#### 工作文档配图
```
用户: 需要一张简洁的图表背景图，用于报告
Claude: [选择默认16:9比例，生成1920x1080专业图片]
```

### 📱 移动设备用途

#### 手机壁纸
```
用户: 生成一张手机壁纸，主题是星空
Claude: [选择mobile_portrait预设，生成832x1440竖屏壁纸]
```

#### 手机头像
```
用户: 我需要一个卡通风格的头像
Claude: [选择mobile_square预设，生成1024x1024正方形头像]
```

### 🌐 社交媒体用途

#### Instagram帖子
```
用户: 为Instagram制作一张美食照片
Claude: [选择instagram_square预设，生成1024x1024正方形图片]
```

#### Facebook封面
```
用户: 需要一张Facebook页面的封面图片，主题是旅行
Claude: [选择facebook_cover预设，生成1184x640封面图片]
```

#### Twitter横幅
```
用户: 制作一个Twitter账号的横幅，展示科技感
Claude: [选择twitter_banner预设，生成1024x512横幅图片]
```

### 🎬 创意和娱乐用途

#### 电影海报风格
```
用户: 创建一张电影海报风格的图片，科幻主题
Claude: [选择cinema_wide预设，生成1408x576宽屏电影比例]
```

#### 艺术创作
```
用户: 生成一幅抽象艺术作品，用于打印
Claude: [选择portrait_4_3预设，生成1024x768传统打印比例]
```

## 🎨 质量和风格选择

### 不同质量级别

#### 日常使用（免费）
```
用户: 生成一张简单的风景图片
Claude: [使用flux-dev模型，免费且质量良好]
```

#### 高质量需求
```
用户: 我需要一张高质量的产品展示图片
Claude: [使用flux-pro模型，更高质量和细节]
```

#### 超高质量（专业用途）
```
用户: 为专业摄影作品集生成一张超高清人像
Claude: [使用flux-pro-1.1-ultra模型，4MP超高分辨率]
```

## 💡 实用技巧

### 🎯 明确用途，获得最佳效果
- ✅ **好的请求**: "为我的咖啡店制作Instagram帖子图片"
- ❌ **模糊请求**: "生成一张图片"

### 🎨 描述风格和细节
- ✅ **详细描述**: "温暖的咖啡店内景，柔和的灯光，木质家具，有人在阅读"
- ❌ **过于简单**: "咖啡店"

### 📐 让AI选择尺寸
- ✅ **说明用途**: "用作手机壁纸" → AI自动选择竖屏比例
- ✅ **说明平台**: "发布到Instagram" → AI自动选择正方形
- ✅ **说明设备**: "桌面显示器背景" → AI自动选择16:9宽屏

## 🔧 高级用法

### 特定尺寸需求
```
用户: 我需要一张2048x2048的高分辨率正方形图片
Claude: [使用square_large预设或Ultra模型生成大尺寸图片]
```

### 特殊比例需求
```
用户: 制作一张21:9超宽屏比例的壁纸
Claude: [使用cinema_wide预设，生成1408x576超宽屏图片]
```

## 📁 文件管理

生成的图片会自动保存到本地，包含：
- **图片文件**: 高质量JPG格式
- **信息文件**: 同名TXT文件，包含提示词和生成参数
- **智能命名**: 文件名包含时间、模型、尺寸等信息

示例文件名：
```
20250803_141822_flux-dev_1920x1080_beautiful_sunset_landscape_abc123.jpg
20250803_141822_flux-dev_1920x1080_beautiful_sunset_landscape_abc123.txt
```

## 🎉 开始使用

现在您可以开始了！只需告诉AI：
- 您想要什么样的图片
- 用于什么目的
- 任何特殊要求

AI会自动为您选择最佳的设置和参数，生成完美的图片！

---

*💡 提示：不确定如何描述？试试这样开始："我需要一张用于[用途]的[主题]图片"*
